
//
//  TANGradientView+HS_XObject.m
//  Created by:  Todd Anthony Nathan
//  Date:        Wed Mar 12 22:37:50 GMT-0600 1997
//
//  Implementation code for the required HS_XObject protocol
//  which TANGradientView must adhere to.  I put it here
//  to minimize the 'damage' done that class.
///

//  Use this code at your own risk.  No warrenty is implied or
//  expressed as to its fitness.  All rights are reserved by the author.
//  You are free to use it for commercial gain, but always credit where
//  credit is due.
///

#import "TANGradientView.h"
#import "TANGradientView+HS_XObject.h"
#import <string.h>

@implementation TANGradientView ( HS_XObject )


+ (id <HS_XObject>)HS_newObjectForElement:(id <HS_Proxy>)xElement
				inZone:(NXZone *)zone
{
    NXRect defaultRect = { {0,0}, {0,0} };

    id theElement = [[self allocFromZone:zone] initFrame:&defaultRect];

    return ( theElement );
}


+ (BOOL)HS_allowsNonSharedData
{
    // Curerntly unused, just return NO
    return ( NO );
}


- (void)HS_releaseForElement:(id <HS_Proxy>)xElement
{
    // Free the unused element
    [self free];
    return;
}


// Define the list of supported properties
// This list should always have a NULL as the last entry
static const char *_TANGradientViewProperties[] = {
	"startColor",
	"endColor",
	"rotation",
	"steps",
	NULL
    };
#define TANGradientView_startColor	_TANGradientViewProperties[0]
#define TANGradientView_endColor	_TANGradientViewProperties[1]
#define TANGradientView_rotation	_TANGradientViewProperties[2]
#define TANGradientView_steps	_TANGradientViewProperties[3]


- (const char **)HS_propertyListForElement:(id <HS_Proxy>)xElement
{
    // Return the statically-defined property list
    return ( _TANGradientViewProperties );
}

- (BOOL)HS_hasProperty:(NXAtom)property forElement:(id <HS_Proxy>)xElement
{
	// Locate the property from the list, return YES if found.
    int i = 0;
	int	notFound = 1;

    while ( _TANGradientViewProperties[i] && notFound ) {
		notFound = strcasecmp(property, _TANGradientViewProperties[i++]);
	}

    return ( notFound? NO : YES );
}

- (BOOL)HS_isPropertyWritable:(NXAtom)property
			forElement:(id <HS_Proxy>)xElement 
{
    return ( YES );
}

- (BOOL)HS_getProperty:(NXAtom)property
			into:(id <HS_Value>)container
			forElement:(id <HS_Proxy>)xElement
{
    if ( !strcasecmp ( property, TANGradientView_startColor ) ) {
		[container setColorValue:[self startColor]];
		return ( YES );
	} else if ( !strcasecmp ( property, TANGradientView_endColor ) ) {
		[container setColorValue:[self endColor]];
		return ( YES );
	} else if ( !strcasecmp ( property, TANGradientView_rotation ) ) {
		[container setFloatValue:[self rotation]];
		return ( YES );
	} else if ( !strcasecmp ( property, TANGradientView_steps ) ) {
		[container setIntValue:[self steps]];
		return ( YES );
	}

    return ( NO );
}

- (BOOL)HS_setProperty:(NXAtom)property
		to:(id <HS_Value>)newValue
		forElement:(id <HS_Proxy>)xElement
{
    if ( !strcasecmp ( property, TANGradientView_startColor ) ) {
		[self setStartColor:[newValue colorValue]];
		return ( YES );
    } else if ( !strcasecmp ( property, TANGradientView_endColor ) ) {
		[self setEndColor:[newValue colorValue]];
		return ( YES );
    } else if ( !strcasecmp ( property, TANGradientView_rotation ) ) {
		[self setRotation:[newValue floatValue]];
		return ( YES );
    } else if ( !strcasecmp ( property, TANGradientView_steps ) ) {
		[self setSteps:[newValue intValue]];
		return ( YES );
	}

    return ( NO );
}

@end

