
//
//  TANGradientView.m
//  Created by:  Todd Anthony Nathan
//  Date:        Wed Mar 12 22:38:14 GMT-0600 1997
//
//  The actual definition of the class responsible for
//  drawing the view.  Simple stuff like getter/setter
//  methods.  Archiving and target stuff.  Target methods
//  are here just because this started out as a IB palette,
//  and I thought I would leave them in there for future use.
///

//  Use this code at your own risk.  No warrenty is implied or
//  expressed as to its fitness.  All rights are reserved by the author.
//  You are free to use it for commercial gain, but always credit where
//  credit is due.
///

#import "TANGradientView.h"
#import "wraps.h"

#define	TAN_DEF_ROTATION	( 0.0 )
#define	TAN_DEF_STEPS	( 100 )

@implementation TANGradientView

// Getter and Setter methods
- setStartColor:(NXColor)newColor
{
	startColor = newColor;
	[self display];
	return ( self );
}

- setEndColor:(NXColor)newColor
{
	endColor = newColor;
	[self display];
	return ( self );
}

- setRotation:(float)newRotation
{
	rotation = newRotation;
	[self display];
	return ( self );
}

- setSteps:(int)newSteps
{
	steps = newSteps;
	[self display];
	return ( self );
}

- takeStartColor:sender
{
	NXColor	newColor;

	newColor = [sender color];
	[self setStartColor:newColor];

	return ( self );
}

- takeEndColor:sender
{
	NXColor	newColor;

	newColor = [sender color];
	[self setEndColor:newColor];

	return ( self );
}

- (NXColor) startColor { return ( startColor ); }
- (NXColor) endColor { return ( endColor ); }
- (float) rotation { return ( rotation ); }
- (int) steps { return ( steps ); }

// Overridden Methods
- initFrame:(const NXRect *)frameRect
{
	[super initFrame:frameRect];

	[self setStartColor:NX_COLORBLACK];
	[self setEndColor:NX_COLORWHITE];
	[self setRotation:TAN_DEF_ROTATION];
	[self setSteps:TAN_DEF_STEPS];

	return ( self );
}

- drawSelf:(const NXRect *)rects :(int)rectCount
{
	float	r1, g1, b1, r2, g2, b2;

	r1 = NXRedComponent([self startColor]);
	g1 = NXGreenComponent([self startColor]);
	b1 = NXBlueComponent([self startColor]);
	r2 = NXRedComponent([self endColor]);
	g2 = NXGreenComponent([self endColor]);
	b2 = NXBlueComponent([self endColor]);

	PSmoveto(NX_X(&bounds), NX_Y(&bounds));
	PSlineto(0.0, NX_HEIGHT(&bounds));
	PSlineto(NX_WIDTH(&bounds), NX_HEIGHT(&bounds));
	PSlineto(NX_WIDTH(&bounds), 0.0);
	PSclosepath();
	PSWGradientFill(r1, g1, b1, r2, g2, b2, [self steps], [self rotation]);

	return ( self );
}

- read:(NXTypedStream *)stream
{
	[super read:stream];

	startColor = NXReadColor(stream);
	endColor = NXReadColor(stream);
	(void) NXReadTypes(stream, "if", &steps, &rotation);

	return ( self );
}

- write:(NXTypedStream *)stream
{
	[super write:stream];

	(void) NXWriteColor(stream, startColor);
	(void) NXWriteColor(stream, endColor);
	(void) NXWriteTypes(stream, "if", &steps, &rotation);

	return ( self );
}

@end